import * as i0 from '@angular/core';
import { signal, computed, Injectable, inject, ChangeDetectorRef, input, output, effect, Component, ChangeDetectionStrategy } from '@angular/core';
import { Subject } from 'rxjs';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';

var EToastTag;
(function (EToastTag) {
    EToastTag["danger"] = "DANGER";
    EToastTag["success"] = "SUCCESS";
    EToastTag["info"] = "INFO";
    EToastTag["warning"] = "WARNING";
})(EToastTag || (EToastTag = {}));
const ToastTagMap = {
    [EToastTag.danger]: 0,
    [EToastTag.success]: 1,
    [EToastTag.info]: 2,
    [EToastTag.warning]: 3,
};
const ToastTagReverseMap = {
    0: EToastTag.danger,
    1: EToastTag.success,
    2: EToastTag.info,
    3: EToastTag.warning,
};
var EToastPosition;
(function (EToastPosition) {
    EToastPosition["top"] = "top";
    EToastPosition["bottom"] = "bottom";
    EToastPosition["left"] = "left";
    EToastPosition["right"] = "right";
})(EToastPosition || (EToastPosition = {}));

class ToastNotificationsService {
    constructor() {
        this._toastNotifications = signal({});
        this.toastNotifications = computed(() => Object.values(this._toastNotifications()));
        this.toastConfig = signal({
            position: EToastPosition.bottom,
            duration: 5000,
        });
        this._config = signal({
            showExpansionButton: true,
            xPosition: 'left',
        });
        this.config = computed(() => this._config());
        this.generateUUID = () => {
            let d = new Date().getTime();
            let d2 = (typeof performance !== 'undefined' && performance.now && performance.now() * 1000) || 0; //Time in microseconds since page-load or 0 if unsupported
            return 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, (c) => {
                let r = Math.random() * 16; //random number between 0 and 16
                if (d > 0) {
                    //Use timestamp until depleted
                    r = (d + r) % 16 | 0;
                    d = Math.floor(d / 16);
                }
                else {
                    //Use microseconds since page-load if supported
                    r = (d2 + r) % 16 | 0;
                    d2 = Math.floor(d2 / 16);
                }
                return (c === 'x' ? r : (r & 0x3) | 0x8).toString(16);
            });
        };
        this.addToastNotification = (item) => {
            const id = this.generateUUID();
            const { duration: defaultDuration } = this.toastConfig(), duration = item.manuallyDismiss ? null : item.duration || defaultDuration, closed = new Subject(), formattedItem = this.formatToast({
                ...item,
                duration,
                datetime: Date.now(),
                id,
                closed,
                expandable: false,
            });
            this._toastNotifications.update((map) => ({
                ...map,
                [id]: formattedItem,
            }));
            this.handleDuration(formattedItem);
            return {
                id,
                update: (update) => this.updateToastNotification(id, update),
                close: () => this.closeToastNotification(id, false),
                loader: {
                    play: () => this.updateToastNotification(id, { loading: true }),
                    stop: () => this.updateToastNotification(id, { loading: false }),
                },
                closed: closed,
            };
        };
        this.formatToast = (item) => {
            item._tag =
                typeof item.tag == 'string' ? item.tag : ToastTagReverseMap[item.tag] || EToastTag.info;
            item._iconClass =
                item.iconClass ||
                    `fa fa-${item._tag == EToastTag.success
                        ? 'check-circle'
                        : item._tag == EToastTag.info
                            ? 'info-circle'
                            : 'warning'}`;
            item.expandable = !!item.body;
            return item;
        };
        this.handleDuration = (item) => {
            if (item?.duration != null)
                setTimeout(() => this.closeToastNotification(item.id, false), item.duration || 0);
        };
        this.updateToastNotification = (id, item) => {
            this._toastNotifications.update((map) => {
                if (!map[id])
                    return map;
                const f = this.formatToast({ ...map[id], ...item });
                this.handleDuration({ id, duration: f.duration });
                return { ...map, [id]: f };
            });
        };
        this.toggleToastNotification = (id, expand) => this._toastNotifications.update((map) => {
            if (!map[id])
                return map;
            return {
                ...map,
                [id]: { ...map[id], expanded: expand == null ? !map[id].expanded : expand },
            };
        });
        this.closeToastNotification = (id, manualDismissal) => {
            return this._toastNotifications.update((map) => {
                map[id].closed.next({ manuallyClosed: manualDismissal });
                delete map[id];
                return { ...map };
            });
        };
    }
    updateConfig(val) {
        this._config.update((config) => ({ ...config, ...val }));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.3", ngImport: i0, type: ToastNotificationsService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.0.3", ngImport: i0, type: ToastNotificationsService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.3", ngImport: i0, type: ToastNotificationsService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

class ToastNotificationsComponent {
    constructor() {
        this.service = inject(ToastNotificationsService);
        this.cdr = inject(ChangeDetectorRef);
        this._showExpansionButton = input(undefined, {
            alias: 'showExpansionButton',
        });
        this._xPosition = input(undefined, {
            alias: 'xPosition',
        });
        this._expandHandler = input(undefined, {
            alias: 'expandHandler',
        });
        this.expanded = output();
        this.showExpansionButton = computed(() => {
            const genConfig = this.service.config();
            return this._showExpansionButton() != null
                ? this._showExpansionButton()
                : genConfig?.showExpansionButton;
        });
        this.xPosition = computed(() => {
            const genConfig = this.service.config();
            return this._xPosition() != null ? this._xPosition() : genConfig?.xPosition;
        });
        this.expandHandler = computed(() => {
            const genConfig = this.service.config();
            return this._expandHandler() != null ? this._expandHandler() : genConfig?.expandHandler;
        });
        this.style = computed(() => {
            const xPosition = this.xPosition();
            if (xPosition == 'right')
                return { right: 0 };
            else if (xPosition == 'left')
                return { left: 0 };
            else if (xPosition == 'center')
                return { left: '50%', right: '50%', transform: 'translate(-50%, 0%)' };
            return {};
        });
        this.notifications = computed(() => this.service.toastNotifications());
        this.notificationsEffect = effect(() => {
            this.notifications();
            this.cdr.markForCheck();
            setTimeout(() => this.cdr.markForCheck(), 500);
            setTimeout(() => this.cdr.markForCheck(), 1000);
        });
        this.add = this.service.addToastNotification;
        this.close = this.service.closeToastNotification;
        this.update = this.service.updateToastNotification;
    }
    expand(item) {
        this.expandHandler()?.(item);
        this.expanded.emit(item);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.3", ngImport: i0, type: ToastNotificationsComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "18.0.3", type: ToastNotificationsComponent, isStandalone: true, selector: "toast-notifications", inputs: { _showExpansionButton: { classPropertyName: "_showExpansionButton", publicName: "showExpansionButton", isSignal: true, isRequired: false, transformFunction: null }, _xPosition: { classPropertyName: "_xPosition", publicName: "xPosition", isSignal: true, isRequired: false, transformFunction: null }, _expandHandler: { classPropertyName: "_expandHandler", publicName: "expandHandler", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { expanded: "expanded" }, ngImport: i0, template: "<div class=\"toast-list\" [style]=\"style()\">\n  @for (item of notifications(); track item.id) {\n    <div class=\"toast-item toast-tag-{{ item._tag | lowercase }} {{ item.toastClass }} \">\n      <div class=\"toast-item-content\" [style.width]=\"'calc(100% - ' + side.offsetWidth + 'px )'\">\n        <div\n          class=\"toast-item-header\"\n          [ngClass]=\"{ compact: !item.expanded }\"\n          (click)=\"service.toggleToastNotification(item.id)\"\n        >\n          <i class=\"toast-icon {{ item._iconClass }}\"></i>\n          <span [innerHTML]=\"item.header\"></span>\n        </div>\n        <!-- <hr [hidden]=\"!item.expanded\" class=\"toast-item-divider\" /> -->\n        <div\n          [hidden]=\"!item.expanded || !item.expandable\"\n          class=\"toast-item-body\"\n          [innerHTML]=\"item.body\"\n        ></div>\n      </div>\n      <div class=\"d-flex align-items-center\" #side>\n        @if (item.loading) {\n          <div class=\"toast-item-loader\">\n            <i class=\"fa fa-spinner fa-spin\"></i>\n          </div>\n        }\n        <div class=\"toast-item-action\">\n          @if (showExpansionButton() && item.expandable) {\n            <button class=\"cbtn\" (click)=\"expand(item)\">\n              <i class=\"fa fa-expand\"></i>\n            </button>\n          }\n          <button class=\"cbtn\" (click)=\"service.closeToastNotification(item.id, true)\">\n            <i class=\"fa fa-close\"></i>\n          </button>\n        </div>\n      </div>\n    </div>\n  }\n</div>\n", styles: ["::ng-deep .toast-list{display:block;position:fixed;z-index:1000;bottom:0;padding:0 10px;width:min(100%,400px);--toast-color: #000;--toast-blur: blur(1.5px);--toast-danger-color: red;--toast-success-color: #00d100;--toast-info-color: rgb(45, 143, 255);--toast-warning-color: #c4ca00;--toast-icon-color: var(--toast-color, #fff);--toast-loader-color: var(--toast-color);--mdc-circular-progress-active-indicator-color: var(--toast-loader-color);--toast-background-color: #dbdbdb80;max-height:90vh;overflow-y:auto}::ng-deep .toast-list .toast-item{--toast-item-radius: 10px;--item-margin: 5px;display:flex;align-items:center;color:var(--toast-color);background-color:var(--toast-background-color);backdrop-filter:var(--toast-blur);-webkit-backdrop-filter:var(--toast-blur);border-radius:var(--toast-item-radius);margin-top:calc(var(--item-margin) * 2);margin-bottom:var(--item-margin);border:1px solid var(--toast-icon-color);background-image:linear-gradient(225deg,rgba(0,0,0,.1019607843),transparent)}::ng-deep .toast-list .toast-item .toast-item-content{padding:var(--item-margin) calc(var(--item-margin) * 2)}::ng-deep .toast-list .toast-item .toast-item-content .toast-item-header{cursor:pointer;font-size:14px;display:flex;align-items:center}::ng-deep .toast-list .toast-item .toast-item-content .toast-item-header.compact{text-overflow:ellipsis;white-space:nowrap;overflow:hidden;word-wrap:break-word}::ng-deep .toast-list .toast-item .toast-item-content .toast-item-body{font-size:13px;word-wrap:break-word;opacity:.8;white-space:break-spaces}::ng-deep .toast-list .toast-item .toast-item-content .toast-item-divider{opacity:.3;border:1px solid var(--toast-color);margin-top:1px;margin-bottom:0;width:30%}::ng-deep .toast-list .toast-item .toast-item-action{color:var(--toast-color);padding-right:2px;cursor:pointer;display:flex;align-items:center}::ng-deep .toast-list .toast-item .toast-item-action .cbtn{color:var(--toast-color);border:none;background-color:transparent;outline:none}::ng-deep .toast-list .toast-item .toast-icon{color:var(--toast-icon-color);margin-right:5px}::ng-deep .toast-list .toast-tag-danger{--toast-icon-color: var(--toast-danger-color)}::ng-deep .toast-list .toast-tag-success{--toast-icon-color: var(--toast-success-color)}::ng-deep .toast-list .toast-tag-info{--toast-icon-color: var(--toast-info-color)}::ng-deep .toast-list .toast-tag-warning{--toast-icon-color: var(--toast-warning-color)}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "pipe", type: i1.LowerCasePipe, name: "lowercase" }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.3", ngImport: i0, type: ToastNotificationsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'toast-notifications', standalone: true, changeDetection: ChangeDetectionStrategy.OnPush, imports: [CommonModule], template: "<div class=\"toast-list\" [style]=\"style()\">\n  @for (item of notifications(); track item.id) {\n    <div class=\"toast-item toast-tag-{{ item._tag | lowercase }} {{ item.toastClass }} \">\n      <div class=\"toast-item-content\" [style.width]=\"'calc(100% - ' + side.offsetWidth + 'px )'\">\n        <div\n          class=\"toast-item-header\"\n          [ngClass]=\"{ compact: !item.expanded }\"\n          (click)=\"service.toggleToastNotification(item.id)\"\n        >\n          <i class=\"toast-icon {{ item._iconClass }}\"></i>\n          <span [innerHTML]=\"item.header\"></span>\n        </div>\n        <!-- <hr [hidden]=\"!item.expanded\" class=\"toast-item-divider\" /> -->\n        <div\n          [hidden]=\"!item.expanded || !item.expandable\"\n          class=\"toast-item-body\"\n          [innerHTML]=\"item.body\"\n        ></div>\n      </div>\n      <div class=\"d-flex align-items-center\" #side>\n        @if (item.loading) {\n          <div class=\"toast-item-loader\">\n            <i class=\"fa fa-spinner fa-spin\"></i>\n          </div>\n        }\n        <div class=\"toast-item-action\">\n          @if (showExpansionButton() && item.expandable) {\n            <button class=\"cbtn\" (click)=\"expand(item)\">\n              <i class=\"fa fa-expand\"></i>\n            </button>\n          }\n          <button class=\"cbtn\" (click)=\"service.closeToastNotification(item.id, true)\">\n            <i class=\"fa fa-close\"></i>\n          </button>\n        </div>\n      </div>\n    </div>\n  }\n</div>\n", styles: ["::ng-deep .toast-list{display:block;position:fixed;z-index:1000;bottom:0;padding:0 10px;width:min(100%,400px);--toast-color: #000;--toast-blur: blur(1.5px);--toast-danger-color: red;--toast-success-color: #00d100;--toast-info-color: rgb(45, 143, 255);--toast-warning-color: #c4ca00;--toast-icon-color: var(--toast-color, #fff);--toast-loader-color: var(--toast-color);--mdc-circular-progress-active-indicator-color: var(--toast-loader-color);--toast-background-color: #dbdbdb80;max-height:90vh;overflow-y:auto}::ng-deep .toast-list .toast-item{--toast-item-radius: 10px;--item-margin: 5px;display:flex;align-items:center;color:var(--toast-color);background-color:var(--toast-background-color);backdrop-filter:var(--toast-blur);-webkit-backdrop-filter:var(--toast-blur);border-radius:var(--toast-item-radius);margin-top:calc(var(--item-margin) * 2);margin-bottom:var(--item-margin);border:1px solid var(--toast-icon-color);background-image:linear-gradient(225deg,rgba(0,0,0,.1019607843),transparent)}::ng-deep .toast-list .toast-item .toast-item-content{padding:var(--item-margin) calc(var(--item-margin) * 2)}::ng-deep .toast-list .toast-item .toast-item-content .toast-item-header{cursor:pointer;font-size:14px;display:flex;align-items:center}::ng-deep .toast-list .toast-item .toast-item-content .toast-item-header.compact{text-overflow:ellipsis;white-space:nowrap;overflow:hidden;word-wrap:break-word}::ng-deep .toast-list .toast-item .toast-item-content .toast-item-body{font-size:13px;word-wrap:break-word;opacity:.8;white-space:break-spaces}::ng-deep .toast-list .toast-item .toast-item-content .toast-item-divider{opacity:.3;border:1px solid var(--toast-color);margin-top:1px;margin-bottom:0;width:30%}::ng-deep .toast-list .toast-item .toast-item-action{color:var(--toast-color);padding-right:2px;cursor:pointer;display:flex;align-items:center}::ng-deep .toast-list .toast-item .toast-item-action .cbtn{color:var(--toast-color);border:none;background-color:transparent;outline:none}::ng-deep .toast-list .toast-item .toast-icon{color:var(--toast-icon-color);margin-right:5px}::ng-deep .toast-list .toast-tag-danger{--toast-icon-color: var(--toast-danger-color)}::ng-deep .toast-list .toast-tag-success{--toast-icon-color: var(--toast-success-color)}::ng-deep .toast-list .toast-tag-info{--toast-icon-color: var(--toast-info-color)}::ng-deep .toast-list .toast-tag-warning{--toast-icon-color: var(--toast-warning-color)}\n"] }]
        }] });

/*
 * Public API Surface of toast-notifications
 */

/**
 * Generated bundle index. Do not edit.
 */

export { EToastPosition, EToastTag, ToastNotificationsComponent, ToastNotificationsService, ToastTagMap, ToastTagReverseMap };
//# sourceMappingURL=serene-dev-toast-notifications.mjs.map
